import { useState, useEffect } from 'react'
import type { ChecklistItem } from '../types'

interface DependencyManagerProps {
  item: ChecklistItem
  allItems: ChecklistItem[]
  onUpdate: (id: number, updates: Partial<ChecklistItem>) => Promise<void>
  onClose: () => void
  isOpen: boolean
}

export default function DependencyManager({ 
  item, 
  allItems, 
  onUpdate, 
  onClose, 
  isOpen 
}: DependencyManagerProps) {
  const [selectedDependencies, setSelectedDependencies] = useState<number[]>([])
  const [isUpdating, setIsUpdating] = useState(false)

  useEffect(() => {
    if (isOpen) {
      setSelectedDependencies(item.dependencies || [])
    }
  }, [isOpen, item.dependencies])

  const handleSave = async () => {
    setIsUpdating(true)
    try {
      await onUpdate(item.id, { dependencies: selectedDependencies })
      onClose()
    } catch (error) {
      console.error('Failed to update dependencies:', error)
    } finally {
      setIsUpdating(false)
    }
  }

  const toggleDependency = (depId: number) => {
    setSelectedDependencies(prev => 
      prev.includes(depId) 
        ? prev.filter(id => id !== depId)
        : [...prev, depId]
    )
  }

  const availableItems = allItems.filter(otherItem => 
    otherItem.id !== item.id && 
    !otherItem.dependencies?.includes(item.id) // Prevent circular dependencies
  )

  if (!isOpen) return null

  return (
    <div className="fixed inset-0 bg-black bg-opacity-50 flex items-center justify-center z-50">
      <div className="bg-white dark:bg-gray-800 rounded-lg shadow-xl max-w-md w-full mx-4 max-h-[80vh] overflow-hidden">
        <div className="p-6">
          <div className="flex items-center justify-between mb-4">
            <h3 className="text-lg font-semibold text-gray-900 dark:text-white">
              Manage Dependencies
            </h3>
            <button
              onClick={onClose}
              className="text-gray-400 hover:text-gray-600 dark:hover:text-gray-300"
            >
              <svg className="w-6 h-6" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M6 18L18 6M6 6l12 12" />
              </svg>
            </button>
          </div>

          <div className="mb-4">
            <p className="text-sm text-gray-600 dark:text-gray-300 mb-3">
              Select items that must be completed before "{item.content}" can be completed:
            </p>
          </div>

          <div className="max-h-64 overflow-y-auto border border-gray-200 dark:border-gray-700 rounded-lg">
            {availableItems.length === 0 ? (
              <div className="p-4 text-center text-gray-500 dark:text-gray-400">
                No available items to depend on
              </div>
            ) : (
              <div className="divide-y divide-gray-200 dark:divide-gray-700">
                {availableItems.map(otherItem => (
                  <label
                    key={otherItem.id}
                    className="flex items-center p-3 hover:bg-gray-50 dark:hover:bg-gray-700 cursor-pointer"
                  >
                    <input
                      type="checkbox"
                      checked={selectedDependencies.includes(otherItem.id)}
                      onChange={() => toggleDependency(otherItem.id)}
                      className="w-4 h-4 text-blue-600 bg-white dark:bg-gray-800 border-2 border-gray-300 dark:border-gray-600 rounded focus:ring-2 focus:ring-blue-500 focus:ring-offset-2 dark:focus:ring-offset-gray-800"
                    />
                    <span className={`ml-3 text-sm ${
                      otherItem.checked 
                        ? 'line-through text-gray-500 dark:text-gray-500' 
                        : 'text-gray-900 dark:text-gray-100'
                    }`}>
                      {otherItem.content}
                    </span>
                    {otherItem.checked && (
                      <span className="ml-2 text-xs text-green-600 dark:text-green-400 bg-green-50 dark:bg-green-900/20 px-2 py-1 rounded-full">
                        ✓ Done
                      </span>
                    )}
                  </label>
                ))}
              </div>
            )}
          </div>

          <div className="flex justify-end gap-3 mt-6">
            <button
              onClick={onClose}
              className="px-4 py-2 text-gray-700 dark:text-gray-300 bg-gray-100 dark:bg-gray-700 rounded-lg hover:bg-gray-200 dark:hover:bg-gray-600 transition-colors duration-200"
            >
              Cancel
            </button>
            <button
              onClick={handleSave}
              disabled={isUpdating}
              className="px-4 py-2 bg-blue-600 dark:bg-blue-500 text-white rounded-lg hover:bg-blue-700 dark:hover:bg-blue-600 disabled:opacity-50 disabled:cursor-not-allowed transition-colors duration-200"
            >
              {isUpdating ? 'Saving...' : 'Save'}
            </button>
          </div>
        </div>
      </div>
    </div>
  )
} 